summaryrefslogtreecommitdiffstats
path: root/kttsd/filters/sbd/sbdconf.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kttsd/filters/sbd/sbdconf.cpp')
-rw-r--r--kttsd/filters/sbd/sbdconf.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kttsd/filters/sbd/sbdconf.cpp b/kttsd/filters/sbd/sbdconf.cpp
index 0a7ddb9..4fe3c9d 100644
--- a/kttsd/filters/sbd/sbdconf.cpp
+++ b/kttsd/filters/sbd/sbdconf.cpp
@@ -112,11 +112,11 @@ SbdConf::~SbdConf(){
* loaded, so it not necessary to call it in your constructor.
* The plugin should read its configuration from the specified group
* in the specified config file.
* @param config Pointer to a KConfig object.
* @param configGroup Call config->setGroup with this argument before
* loading your configuration.
*/
-void SbdConf::load(KConfig* config, const TQString& configGroup){
+void SbdConf::load(TDEConfig* config, const TQString& configGroup){
// kdDebug() << "SbdConf::load: Running" << endl;
config->setGroup( configGroup );
m_widget->nameLineEdit->setText(
@@ -145,11 +145,11 @@ void SbdConf::load(KConfig* config, const TQString& configGroup){
* configuration is stored. The method is called when the user clicks "Apply"
* or "Ok". The plugin should save its configuration in the specified
* group of the specified config file.
* @param config Pointer to a KConfig object.
* @param configGroup Call config->setGroup with this argument before
* saving your configuration.
*/
-void SbdConf::save(KConfig* config, const TQString& configGroup){
+void SbdConf::save(TDEConfig* config, const TQString& configGroup){
// kdDebug() << "SbdConf::save: Running" << endl;
config->setGroup( configGroup );
config->writeEntry("UserFilterName", m_widget->nameLineEdit->text() );
@@ -310,7 +310,7 @@ void SbdConf::slotLoadButton_clicked()
m_widget,
"sbd_loadfile");
if ( filename.isEmpty() ) return;
- KConfig* cfg = new KConfig( filename, true, false, 0 );
+ TDEConfig* cfg = new TDEConfig( filename, true, false, 0 );
load( cfg, "Filter" );
delete cfg;
configChanged();
@@ -324,7 +324,7 @@ void SbdConf::slotSaveButton_clicked()
m_widget,
"sbd_savefile");
if ( filename.isEmpty() ) return;
- KConfig* cfg = new KConfig( filename, false, false, 0 );
+ TDEConfig* cfg = new TDEConfig( filename, false, false, 0 );
save( cfg, "Filter" );
delete cfg;
}
@@ -112,11 +112,11 @@ SbdConf::~SbdConf(){
* The plugin should read its configuration from the specified group
* in the specified config file.
-* @param config Pointer to a KConfig object.
+* @param config Pointer to a TDEConfig object.
* @param configGroup Call config->setGroup with this argument before
* loading your configuration.
@@ -145,11 +145,11 @@ void SbdConf::load(KConfig* config, const TQString& configGroup){
* or "Ok". The plugin should save its configuration in the specified
* group of the specified config file.
-* @param config Pointer to a KConfig object.
+* @param config Pointer to a TDEConfig object.
* @param configGroup Call config->setGroup with this argument before
* saving your configuration.